@@ -77,10 +77,14 @@ class NXtree(NXgroup):
                 self[node.nxname] = node
             elif isinstance(node, NXentry):
                 group = NXroot(node)
-                self[self.get_new_name()] = group
+                name = self.get_new_name()
+                self[name] = group
+                print "NeXpy: '%s' added to tree in '%s'" % (node.nxname, group.nxname)
             else:
                 group = NXroot(NXentry(node))
-                self[self.get_new_name()] = group
+                name = self.get_new_name()
+                self[name] = group
+                print "NeXpy: '%s' added to tree in '%s%s'" % (node.nxname, group.nxname, node.nxgroup.nxpath)
         else:
             raise NeXusError("Only an NXgroup can be added to the tree")
 
@@ -125,15 +129,18 @@ class NXTreeItem(QtGui.QStandardItem):
     A subclass of the QtGui.QStandardItem class to return the data from 
     an NXnode.
     """
-    _lock_icon = os.path.join(os.path.abspath(os.path.dirname(__file__)), 
-                              'resources', 'lock-icon.png')
     _link_icon = os.path.join(os.path.abspath(os.path.dirname(__file__)), 
                               'resources', 'link-icon.png')
+    _lock_icon = os.path.join(os.path.abspath(os.path.dirname(__file__)), 
+                              'resources', 'lock-icon.png')
+    _unlock_icon = os.path.join(os.path.abspath(os.path.dirname(__file__)), 
+                                'resources', 'unlock-icon.png')
 
     def __init__(self, node):
         self.node = node
-        self._locked = QtGui.QIcon(self._lock_icon)
         self._linked = QtGui.QIcon(self._link_icon)
+        self._locked = QtGui.QIcon(self._lock_icon)
+        self._unlocked = QtGui.QIcon(self._unlock_icon)
         super(NXTreeItem, self).__init__(self.node.nxname)
 
     def text(self):
@@ -157,6 +164,8 @@ class NXTreeItem(QtGui.QStandardItem):
         if role == QtCore.Qt.DecorationRole:
             if isinstance(self.node, NXroot) and self.node.nxfilemode == 'r':
                 return self._locked
+            elif isinstance(self.node, NXroot) and self.node.nxfilemode == 'rw':
+                return self._unlocked
             elif isinstance(self.node, NXlink):
                 return self._linked
             else:
